#include "tao/TypeCodeFactory_Adapter.h"

#include "ace/Dynamic_Service.h"

TAO_TypeCodeFactory_Adapter::~TAO_TypeCodeFactory_Adapter ()
{
}

